@@ -1,27 +1,25 @@
-#' @title Merge by Columns in Loops
+#'@title Merge by Columns in Loops
 #'
-#' @description Merges rows by columns in a loop using the \code{\link{enum}}
-#'   function. On first iteration, indicated by \code{\link{enum}}, initiates a
-#'   new data frame with the data to merge as first row. On all following
-#'   iterations, adds data to merge as subsequent rows (using
-#'   \code{\link[plyr:rbind.fill]{plyr:rbind.fill}}).
+#'@description Merges rows by columns in a loop using the \code{\link{enum}}
+#'  function. On first iteration, indicated by \code{\link{enum}}, initiates a
+#'  new \code{\link{data.table}} with the data to merge as first row. On all
+#'  following iterations, adds data to merge as subsequent rows (using
+#'  \code{\link[data.table:rbindlist]{data.table::rbindlist}}).
 #'
-#' @param merged The name of the data frame for the merged data (without
-#'   quotes).
-#' @param ... Any number of data to be merged. Each argument must be one of the
-#'   following: a data frame with either single row or two column; a named
-#'   vector or a named list (with single elements); or a single value with
-#'   parameter name (e.g. date = 1989 or id = "jdoe"). Data with two columns
-#'   will be transposed using first column as column names and second column as
-#'   corresponding values. See Details, Examples.
-#' @param hush Logical. If \code{TRUE} (default), prints message when the data
-#'   frame for merging is initiated.
-#' @param nameless Logical. If \code{FALSE} (default), unnamed vectors or list
-#'   elements are not allowed. If set to \code{TRUE}, unnamed elements will be
-#'   named automatically (e.g. \code{X.value.}).
+#'@param merged The name of the \code{\link{data.table}} for the merged data
+#'  (without quotes).
+#'@param ... Any number of data to be merged. Each argument must be one of the
+#'  following: a \code{\link{data.frame}} (or \code{\link{data.table}}) with
+#'  either single row or two column; a named vector or a named list (with single
+#'  elements); or a single value with parameter name (e.g. date = 1989 or id =
+#'  "jdoe"). Data with two columns will be transposed using first column as
+#'  column names and second column as corresponding values. See Details,
+#'  Examples.
+#'@param hush Logical. If \code{TRUE} (default), prints message when the data
+#'  frame for merging is initiated.
 #'@details In each call, all data passed to the function (via \code{...}) will
 #'  be merged into a single row, and that single row will be added to the
-#'  \code{merged} data frame.
+#'  "\code{merged}" data table.
 #'
 #'  See an extensive example via https://github.com/gasparl/neatstats.
 #'@seealso \code{\link{enum}}
@@ -92,6 +90,25 @@
 #' # with NAs where sqr was not added
 #' print(merged_data)
 #'
+#' # example with data.table added
+#' library('data.table')
+#' for (elem in enum(my_vector)) {
+#'     cat(elem, fill = TRUE)
+#'     dframe = data.frame(item = elem[2],
+#'                         number = elem[1])
+#'     asnum = as.numeric(elem[1])
+#'     dtable = data.table(item2 = paste('DT', elem[2]),
+#'                         number2 = asnum + 9)
+#'     if (asnum %% 2 == 0) {
+#'         dframe$sqr = asnum ** 2
+#'     }
+#'     rbind_loop(merged_data,
+#'                dframe,
+#'                dtable)
+#' }
+#'
+#' print(merged_data)
+#'
 #' # an extensive example to show how to collect and aggregate raw data is
 #' # available via the README file at the repository:
 #' # https://github.com/gasparl/neatstats
@@ -99,11 +116,7 @@
 #' @export
 rbind_loop = function(merged,
                       ...,
-                      hush = FALSE,
-                      nameless = FALSE) {
-    validate_args(match.call(),
-                  list(val_arg(nameless, c('bool'), 1),
-                       val_arg(hush, c('bool'), 1)))
+                      hush = FALSE) {
     merged_str = deparse(substitute(merged))
     if (is.null(pkg.globals$my_unique_first_iter)) {
         stop(
@@ -111,7 +124,7 @@ rbind_loop = function(merged,
             'Please use enum() if you want to use rbind_neat(). See ?rbind_neat for details'
         )
     }
-    to_merge = get_row(..., nameless = nameless)
+    to_merge = get_row(...)
     if (pkg.globals$my_unique_first_iter  == TRUE) {
         if (hush == FALSE) {
             message('Initiated ',
@@ -124,7 +137,7 @@ rbind_loop = function(merged,
         assign(merged_str, to_merge, envir = parent.frame())
     } else if (pkg.globals$my_unique_first_iter  == FALSE) {
         assign(merged_str,
-               plyr::rbind.fill(merged, to_merge),
+               rbindlist(list(merged, to_merge), fill = TRUE),
                envir = parent.frame())
     }
 }
